@@ -1,17 +1,18 @@
 #!/usr/bin/perl
 #-------------------------------------------------------------------------------
-# Perl source filter to filter Unicode representations of operators
+# Perl source filter to filter Unicode representations of some operators
 # Philip R Brenan at gmail dot com, Appa Apps Ltd, 2016
 #-------------------------------------------------------------------------------
 
 package UnicodeOperators;
 use Filter::Util::Call;
-use Data::Dump qw(dump);
+
 sub import
  {my ($type) = @_;
   my ($ref) = [];
   filter_add(bless $ref);
  }
+
 sub filter
  {my ($self) = @_;
   my $status = filter_read();
@@ -23,9 +24,9 @@ sub filter
   $status
  }
 
-$VERSION = '1.001'; # Sunday 18 September 2016
+$VERSION = '1.002'; # Monday 19 September 2016
 
- 1;
+1;
 
 =encoding utf-8
 
@@ -35,7 +36,10 @@ UnicodeOperators - Unicode versions of some Perl operators
 
 =head1 Synopsis
 
+ use UnicodeOperators;
+
  say STDERR sub {$_[0]}∙(2), {a►1, b►2, c►3}∙{a}, "aaa" ○ s/a/b/gsr;
+
  # 21bbb
 
 =head1 Description
